property_value_alias_sc_long_to_short = {
    "Adlam": "Adlm",
    "Ahom": "Ahom",
    "Anatolian_Hieroglyphs": "Hluw",
    "Arabic": "Arab",
    "Armenian": "Armn",
    "Avestan": "Avst",
    "Balinese": "Bali",
    "Bamum": "Bamu",
    "Bassa_Vah": "Bass",
    "Batak": "Batk",
    "Bengali": "Beng",
    "Bhaiksuki": "Bhks",
    "Bopomofo": "Bopo",
    "Brahmi": "Brah",
    "Braille": "Brai",
    "Buginese": "Bugi",
    "Buhid": "Buhd",
    "Canadian_Aboriginal": "Cans",
    "Carian": "Cari",
    "Caucasian_Albanian": "Aghb",
    "Chakma": "Cakm",
    "Cham": "Cham",
    "Cherokee": "Cher",
    "Chorasmian": "Chrs",
    "Common": "Zyyy",
    "Coptic": "Copt",
    "Cuneiform": "Xsux",
    "Cypriot": "Cprt",
    "Cyrillic": "Cyrl",
    "Deseret": "Dsrt",
    "Devanagari": "Deva",
    "Dives_Akuru": "Diak",
    "Dogra": "Dogr",
    "Duployan": "Dupl",
    "Egyptian_Hieroglyphs": "Egyp",
    "Elbasan": "Elba",
    "Elymaic": "Elym",
    "Ethiopic": "Ethi",
    "Georgian": "Geor",
    "Glagolitic": "Glag",
    "Gothic": "Goth",
    "Grantha": "Gran",
    "Greek": "Grek",
    "Gujarati": "Gujr",
    "Gunjala_Gondi": "Gong",
    "Gurmukhi": "Guru",
    "Han": "Hani",
    "Hangul": "Hang",
    "Hanifi_Rohingya": "Rohg",
    "Hanunoo": "Hano",
    "Hatran": "Hatr",
    "Hebrew": "Hebr",
    "Hiragana": "Hira",
    "Imperial_Aramaic": "Armi",
    "Inherited": "Zinh",
    "Inscriptional_Pahlavi": "Phli",
    "Inscriptional_Parthian": "Prti",
    "Javanese": "Java",
    "Kaithi": "Kthi",
    "Kannada": "Knda",
    "Katakana": "Kana",
    "Katakana_Or_Hiragana": "Hrkt",
    "Kayah_Li": "Kali",
    "Kharoshthi": "Khar",
    "Khitan_Small_Script": "Kits",
    "Khmer": "Khmr",
    "Khojki": "Khoj",
    "Khudawadi": "Sind",
    "Lao": "Laoo",
    "Latin": "Latn",
    "Lepcha": "Lepc",
    "Limbu": "Limb",
    "Linear_A": "Lina",
    "Linear_B": "Linb",
    "Lisu": "Lisu",
    "Lycian": "Lyci",
    "Lydian": "Lydi",
    "Mahajani": "Mahj",
    "Makasar": "Maka",
    "Malayalam": "Mlym",
    "Mandaic": "Mand",
    "Manichaean": "Mani",
    "Marchen": "Marc",
    "Masaram_Gondi": "Gonm",
    "Medefaidrin": "Medf",
    "Meetei_Mayek": "Mtei",
    "Mende_Kikakui": "Mend",
    "Meroitic_Cursive": "Merc",
    "Meroitic_Hieroglyphs": "Mero",
    "Miao": "Plrd",
    "Modi": "Modi",
    "Mongolian": "Mong",
    "Mro": "Mroo",
    "Multani": "Mult",
    "Myanmar": "Mymr",
    "Nabataean": "Nbat",
    "Nandinagari": "Nand",
    "New_Tai_Lue": "Talu",
    "Newa": "Newa",
    "Nko": "Nkoo",
    "Nushu": "Nshu",
    "Nyiakeng_Puachue_Hmong": "Hmnp",
    "Ogham": "Ogam",
    "Ol_Chiki": "Olck",
    "Old_Hungarian": "Hung",
    "Old_Italic": "Ital",
    "Old_North_Arabian": "Narb",
    "Old_Permic": "Perm",
    "Old_Persian": "Xpeo",
    "Old_Sogdian": "Sogo",
    "Old_South_Arabian": "Sarb",
    "Old_Turkic": "Orkh",
    "Oriya": "Orya",
    "Osage": "Osge",
    "Osmanya": "Osma",
    "Pahawh_Hmong": "Hmng",
    "Palmyrene": "Palm",
    "Pau_Cin_Hau": "Pauc",
    "Phags_Pa": "Phag",
    "Phoenician": "Phnx",
    "Psalter_Pahlavi": "Phlp",
    "Rejang": "Rjng",
    "Runic": "Runr",
    "Samaritan": "Samr",
    "Saurashtra": "Saur",
    "Sharada": "Shrd",
    "Shavian": "Shaw",
    "Siddham": "Sidd",
    "SignWriting": "Sgnw",
    "Sinhala": "Sinh",
    "Sogdian": "Sogd",
    "Sora_Sompeng": "Sora",
    "Soyombo": "Soyo",
    "Sundanese": "Sund",
    "Syloti_Nagri": "Sylo",
    "Syriac": "Syrc",
    "Tagalog": "Tglg",
    "Tagbanwa": "Tagb",
    "Tai_Le": "Tale",
    "Tai_Tham": "Lana",
    "Tai_Viet": "Tavt",
    "Takri": "Takr",
    "Tamil": "Taml",
    "Tangut": "Tang",
    "Telugu": "Telu",
    "Thaana": "Thaa",
    "Thai": "Thai",
    "Tibetan": "Tibt",
    "Tifinagh": "Tfng",
    "Tirhuta": "Tirh",
    "Ugaritic": "Ugar",
    "Unknown": "Zzzz",
    "Vai": "Vaii",
    "Wancho": "Wcho",
    "Warang_Citi": "Wara",
    "Yezidi": "Yezi",
    "Yi": "Yiii",
    "Zanabazar_Square": "Zanb",
}



property_value_alias_blk_short_to_long = {
    "ASCII": "Basic Latin",
    "Adlam": "Adlam",
    "Aegean Numbers": "Aegean Numbers",
    "Ahom": "Ahom",
    "Alchemical": "Alchemical Symbols",
    "Alphabetic PF": "Alphabetic Presentation Forms",
    "Anatolian Hieroglyphs": "Anatolian Hieroglyphs",
    "Ancient Greek Music": "Ancient Greek Musical Notation",
    "Ancient Greek Numbers": "Ancient Greek Numbers",
    "Ancient Symbols": "Ancient Symbols",
    "Arabic": "Arabic",
    "Arabic Ext A": "Arabic Extended A",
    "Arabic Math": "Arabic Mathematical Alphabetic Symbols",
    "Arabic PF A": "Arabic Presentation Forms A",
    "Arabic PF B": "Arabic Presentation Forms B",
    "Arabic Sup": "Arabic Supplement",
    "Armenian": "Armenian",
    "Arrows": "Arrows",
    "Avestan": "Avestan",
    "Balinese": "Balinese",
    "Bamum": "Bamum",
    "Bamum Sup": "Bamum Supplement",
    "Bassa Vah": "Bassa Vah",
    "Batak": "Batak",
    "Bengali": "Bengali",
    "Bhaiksuki": "Bhaiksuki",
    "Block Elements": "Block Elements",
    "Bopomofo": "Bopomofo",
    "Bopomofo Ext": "Bopomofo Extended",
    "Box Drawing": "Box Drawing",
    "Brahmi": "Brahmi",
    "Braille": "Braille Patterns",
    "Buginese": "Buginese",
    "Buhid": "Buhid",
    "Byzantine Music": "Byzantine Musical Symbols",
    "CJK": "CJK Unified Ideographs",
    "CJK Compat": "CJK Compatibility",
    "CJK Compat Forms": "CJK Compatibility Forms",
    "CJK Compat Ideographs": "CJK Compatibility Ideographs",
    "CJK Compat Ideographs Sup": "CJK Compatibility Ideographs Supplement",
    "CJK Ext A": "CJK Unified Ideographs Extension A",
    "CJK Ext B": "CJK Unified Ideographs Extension B",
    "CJK Ext C": "CJK Unified Ideographs Extension C",
    "CJK Ext D": "CJK Unified Ideographs Extension D",
    "CJK Ext E": "CJK Unified Ideographs Extension E",
    "CJK Ext F": "CJK Unified Ideographs Extension F",
    "CJK Ext G": "CJK Unified Ideographs Extension G",
    "CJK Radicals Sup": "CJK Radicals Supplement",
    "CJK Strokes": "CJK Strokes",
    "CJK Symbols": "CJK Symbols And Punctuation",
    "Carian": "Carian",
    "Caucasian Albanian": "Caucasian Albanian",
    "Chakma": "Chakma",
    "Cham": "Cham",
    "Cherokee": "Cherokee",
    "Cherokee Sup": "Cherokee Supplement",
    "Chess Symbols": "Chess Symbols",
    "Chorasmian": "Chorasmian",
    "Compat Jamo": "Hangul Compatibility Jamo",
    "Control Pictures": "Control Pictures",
    "Coptic": "Coptic",
    "Coptic Epact Numbers": "Coptic Epact Numbers",
    "Counting Rod": "Counting Rod Numerals",
    "Cuneiform": "Cuneiform",
    "Cuneiform Numbers": "Cuneiform Numbers And Punctuation",
    "Currency Symbols": "Currency Symbols",
    "Cypriot Syllabary": "Cypriot Syllabary",
    "Cyrillic": "Cyrillic",
    "Cyrillic Ext A": "Cyrillic Extended A",
    "Cyrillic Ext B": "Cyrillic Extended B",
    "Cyrillic Ext C": "Cyrillic Extended C",
    "Cyrillic Sup": "Cyrillic Supplement",
    "Deseret": "Deseret",
    "Devanagari": "Devanagari",
    "Devanagari Ext": "Devanagari Extended",
    "Diacriticals": "Combining Diacritical Marks",
    "Diacriticals Ext": "Combining Diacritical Marks Extended",
    "Diacriticals For Symbols": "Combining Diacritical Marks For Symbols",
    "Diacriticals Sup": "Combining Diacritical Marks Supplement",
    "Dingbats": "Dingbats",
    "Dives Akuru": "Dives Akuru",
    "Dogra": "Dogra",
    "Domino": "Domino Tiles",
    "Duployan": "Duployan",
    "Early Dynastic Cuneiform": "Early Dynastic Cuneiform",
    "Egyptian Hieroglyph Format Controls": "Egyptian Hieroglyph Format Controls",
    "Egyptian Hieroglyphs": "Egyptian Hieroglyphs",
    "Elbasan": "Elbasan",
    "Elymaic": "Elymaic",
    "Emoticons": "Emoticons",
    "Enclosed Alphanum": "Enclosed Alphanumerics",
    "Enclosed Alphanum Sup": "Enclosed Alphanumeric Supplement",
    "Enclosed CJK": "Enclosed CJK Letters And Months",
    "Enclosed Ideographic Sup": "Enclosed Ideographic Supplement",
    "Ethiopic": "Ethiopic",
    "Ethiopic Ext": "Ethiopic Extended",
    "Ethiopic Ext A": "Ethiopic Extended A",
    "Ethiopic Sup": "Ethiopic Supplement",
    "Geometric Shapes": "Geometric Shapes",
    "Geometric Shapes Ext": "Geometric Shapes Extended",
    "Georgian": "Georgian",
    "Georgian Ext": "Georgian Extended",
    "Georgian Sup": "Georgian Supplement",
    "Glagolitic": "Glagolitic",
    "Glagolitic Sup": "Glagolitic Supplement",
    "Gothic": "Gothic",
    "Grantha": "Grantha",
    "Greek": "Greek And Coptic",
    "Greek Ext": "Greek Extended",
    "Gujarati": "Gujarati",
    "Gunjala Gondi": "Gunjala Gondi",
    "Gurmukhi": "Gurmukhi",
    "Half And Full Forms": "Halfwidth And Fullwidth Forms",
    "Half Marks": "Combining Half Marks",
    "Hangul": "Hangul Syllables",
    "Hanifi Rohingya": "Hanifi Rohingya",
    "Hanunoo": "Hanunoo",
    "Hatran": "Hatran",
    "Hebrew": "Hebrew",
    "High PU Surrogates": "High Private Use Surrogates",
    "High Surrogates": "High Surrogates",
    "Hiragana": "Hiragana",
    "IDC": "Ideographic Description Characters",
    "IPA Ext": "IPA Extensions",
    "Ideographic Symbols": "Ideographic Symbols And Punctuation",
    "Imperial Aramaic": "Imperial Aramaic",
    "Indic Number Forms": "Common Indic Number Forms",
    "Indic Siyaq Numbers": "Indic Siyaq Numbers",
    "Inscriptional Pahlavi": "Inscriptional Pahlavi",
    "Inscriptional Parthian": "Inscriptional Parthian",
    "Jamo": "Hangul Jamo",
    "Jamo Ext A": "Hangul Jamo Extended A",
    "Jamo Ext B": "Hangul Jamo Extended B",
    "Javanese": "Javanese",
    "Kaithi": "Kaithi",
    "Kana Ext A": "Kana Extended A",
    "Kana Sup": "Kana Supplement",
    "Kanbun": "Kanbun",
    "Kangxi": "Kangxi Radicals",
    "Kannada": "Kannada",
    "Katakana": "Katakana",
    "Katakana Ext": "Katakana Phonetic Extensions",
    "Kayah Li": "Kayah Li",
    "Kharoshthi": "Kharoshthi",
    "Khitan Small Script": "Khitan Small Script",
    "Khmer": "Khmer",
    "Khmer Symbols": "Khmer Symbols",
    "Khojki": "Khojki",
    "Khudawadi": "Khudawadi",
    "Lao": "Lao",
    "Latin 1 Sup": "Latin 1 Supplement",
    "Latin Ext A": "Latin Extended A",
    "Latin Ext Additional": "Latin Extended Additional",
    "Latin Ext B": "Latin Extended B",
    "Latin Ext C": "Latin Extended C",
    "Latin Ext D": "Latin Extended D",
    "Latin Ext E": "Latin Extended E",
    "Lepcha": "Lepcha",
    "Letterlike Symbols": "Letterlike Symbols",
    "Limbu": "Limbu",
    "Linear A": "Linear A",
    "Linear B Ideograms": "Linear B Ideograms",
    "Linear B Syllabary": "Linear B Syllabary",
    "Lisu": "Lisu",
    "Lisu Sup": "Lisu Supplement",
    "Low Surrogates": "Low Surrogates",
    "Lycian": "Lycian",
    "Lydian": "Lydian",
    "Mahajani": "Mahajani",
    "Mahjong": "Mahjong Tiles",
    "Makasar": "Makasar",
    "Malayalam": "Malayalam",
    "Mandaic": "Mandaic",
    "Manichaean": "Manichaean",
    "Marchen": "Marchen",
    "Masaram Gondi": "Masaram Gondi",
    "Math Alphanum": "Mathematical Alphanumeric Symbols",
    "Math Operators": "Mathematical Operators",
    "Mayan Numerals": "Mayan Numerals",
    "Medefaidrin": "Medefaidrin",
    "Meetei Mayek": "Meetei Mayek",
    "Meetei Mayek Ext": "Meetei Mayek Extensions",
    "Mende Kikakui": "Mende Kikakui",
    "Meroitic Cursive": "Meroitic Cursive",
    "Meroitic Hieroglyphs": "Meroitic Hieroglyphs",
    "Miao": "Miao",
    "Misc Arrows": "Miscellaneous Symbols And Arrows",
    "Misc Math Symbols A": "Miscellaneous Mathematical Symbols A",
    "Misc Math Symbols B": "Miscellaneous Mathematical Symbols B",
    "Misc Pictographs": "Miscellaneous Symbols And Pictographs",
    "Misc Symbols": "Miscellaneous Symbols",
    "Misc Technical": "Miscellaneous Technical",
    "Modi": "Modi",
    "Modifier Letters": "Spacing Modifier Letters",
    "Modifier Tone Letters": "Modifier Tone Letters",
    "Mongolian": "Mongolian",
    "Mongolian Sup": "Mongolian Supplement",
    "Mro": "Mro",
    "Multani": "Multani",
    "Music": "Musical Symbols",
    "Myanmar": "Myanmar",
    "Myanmar Ext A": "Myanmar Extended A",
    "Myanmar Ext B": "Myanmar Extended B",
    "NB": "No Block",
    "NKo": "NKo",
    "Nabataean": "Nabataean",
    "Nandinagari": "Nandinagari",
    "New Tai Lue": "New Tai Lue",
    "Newa": "Newa",
    "Number Forms": "Number Forms",
    "Nushu": "Nushu",
    "Nyiakeng Puachue Hmong": "Nyiakeng Puachue Hmong",
    "OCR": "Optical Character Recognition",
    "Ogham": "Ogham",
    "Ol Chiki": "Ol Chiki",
    "Old Hungarian": "Old Hungarian",
    "Old Italic": "Old Italic",
    "Old North Arabian": "Old North Arabian",
    "Old Permic": "Old Permic",
    "Old Persian": "Old Persian",
    "Old Sogdian": "Old Sogdian",
    "Old South Arabian": "Old South Arabian",
    "Old Turkic": "Old Turkic",
    "Oriya": "Oriya",
    "Ornamental Dingbats": "Ornamental Dingbats",
    "Osage": "Osage",
    "Osmanya": "Osmanya",
    "Ottoman Siyaq Numbers": "Ottoman Siyaq Numbers",
    "PUA": "Private Use Area",
    "Pahawh Hmong": "Pahawh Hmong",
    "Palmyrene": "Palmyrene",
    "Pau Cin Hau": "Pau Cin Hau",
    "Phags Pa": "Phags Pa",
    "Phaistos": "Phaistos Disc",
    "Phoenician": "Phoenician",
    "Phonetic Ext": "Phonetic Extensions",
    "Phonetic Ext Sup": "Phonetic Extensions Supplement",
    "Playing Cards": "Playing Cards",
    "Psalter Pahlavi": "Psalter Pahlavi",
    "Punctuation": "General Punctuation",
    "Rejang": "Rejang",
    "Rumi": "Rumi Numeral Symbols",
    "Runic": "Runic",
    "Samaritan": "Samaritan",
    "Saurashtra": "Saurashtra",
    "Sharada": "Sharada",
    "Shavian": "Shavian",
    "Shorthand Format Controls": "Shorthand Format Controls",
    "Siddham": "Siddham",
    "Sinhala": "Sinhala",
    "Sinhala Archaic Numbers": "Sinhala Archaic Numbers",
    "Small Forms": "Small Form Variants",
    "Small Kana Ext": "Small Kana Extension",
    "Sogdian": "Sogdian",
    "Sora Sompeng": "Sora Sompeng",
    "Soyombo": "Soyombo",
    "Specials": "Specials",
    "Sundanese": "Sundanese",
    "Sundanese Sup": "Sundanese Supplement",
    "Sup Arrows A": "Supplemental Arrows A",
    "Sup Arrows B": "Supplemental Arrows B",
    "Sup Arrows C": "Supplemental Arrows C",
    "Sup Math Operators": "Supplemental Mathematical Operators",
    "Sup PUA A": "Supplementary Private Use Area A",
    "Sup PUA B": "Supplementary Private Use Area B",
    "Sup Punctuation": "Supplemental Punctuation",
    "Sup Symbols And Pictographs": "Supplemental Symbols And Pictographs",
    "Super And Sub": "Superscripts And Subscripts",
    "Sutton SignWriting": "Sutton SignWriting",
    "Syloti Nagri": "Syloti Nagri",
    "Symbols And Pictographs Ext A": "Symbols And Pictographs Extended A",
    "Symbols For Legacy Computing": "Symbols For Legacy Computing",
    "Syriac": "Syriac",
    "Syriac Sup": "Syriac Supplement",
    "Tagalog": "Tagalog",
    "Tagbanwa": "Tagbanwa",
    "Tags": "Tags",
    "Tai Le": "Tai Le",
    "Tai Tham": "Tai Tham",
    "Tai Viet": "Tai Viet",
    "Tai Xuan Jing": "Tai Xuan Jing Symbols",
    "Takri": "Takri",
    "Tamil": "Tamil",
    "Tamil Sup": "Tamil Supplement",
    "Tangut": "Tangut",
    "Tangut Components": "Tangut Components",
    "Tangut Sup": "Tangut Supplement",
    "Telugu": "Telugu",
    "Thaana": "Thaana",
    "Thai": "Thai",
    "Tibetan": "Tibetan",
    "Tifinagh": "Tifinagh",
    "Tirhuta": "Tirhuta",
    "Transport And Map": "Transport And Map Symbols",
    "UCAS": "Unified Canadian Aboriginal Syllabics",
    "UCAS Ext": "Unified Canadian Aboriginal Syllabics Extended",
    "Ugaritic": "Ugaritic",
    "VS": "Variation Selectors",
    "VS Sup": "Variation Selectors Supplement",
    "Vai": "Vai",
    "Vedic Ext": "Vedic Extensions",
    "Vertical Forms": "Vertical Forms",
    "Wancho": "Wancho",
    "Warang Citi": "Warang Citi",
    "Yezidi": "Yezidi",
    "Yi Radicals": "Yi Radicals",
    "Yi Syllables": "Yi Syllables",
    "Yijing": "Yijing Hexagram Symbols",
    "Zanabazar Square": "Zanabazar Square",
}



property_value_alias_bc_long_to_short = {
    "Arabic_Letter": "AL",
    "Arabic_Number": "AN",
    "Boundary_Neutral": "BN",
    "Common_Separator": "CS",
    "European_Number": "EN",
    "European_Separator": "ES",
    "European_Terminator": "ET",
    "First_Strong_Isolate": "FSI",
    "Left_To_Right": "L",
    "Left_To_Right_Embedding": "LRE",
    "Left_To_Right_Isolate": "LRI",
    "Left_To_Right_Override": "LRO",
    "Nonspacing_Mark": "NSM",
    "Other_Neutral": "ON",
    "Paragraph_Separator": "B",
    "Pop_Directional_Format": "PDF",
    "Pop_Directional_Isolate": "PDI",
    "Right_To_Left": "R",
    "Right_To_Left_Embedding": "RLE",
    "Right_To_Left_Isolate": "RLI",
    "Right_To_Left_Override": "RLO",
    "Segment_Separator": "S",
    "White_Space": "WS",
}
